@@ -19,11 +19,19 @@ before any blocking operation and the ØMQ file descriptor is polled internally
 to trigger needed events.
 """
 
+from zmq import *
+from zmq import devices
 import gevent_zeromq.core as zmq
-zmq.Context = zmq._Context
-zmq.Socket = zmq._Socket
+from gevent_zeromq.poll import GreenPoller
 
-def monkey_patch(test_suite=False):
+zmq.Socket = zmq.GreenSocket
+zmq.Context = zmq.GreenContext
+zmq.Poller = GreenPoller
+Socket = zmq.GreenSocket
+Context = zmq.GreenContext
+Poller = GreenPoller
+
+def monkey_patch():
     """
     Monkey patches `zmq.Context` and `zmq.Socket`
     
@@ -31,9 +39,8 @@ def monkey_patch(test_suite=False):
     compatibility as well.
     """
     ozmq = __import__('zmq')
-    ozmq.Socket = zmq.Socket
-    ozmq.Context = zmq.Context
+    ozmq.Socket = zmq.GreenSocket
+    ozmq.Context = zmq.GreenContext
+    ozmq.Poller = GreenPoller
 
-    if test_suite:
-        from gevent_zeromq.tests import monkey_patch_test_suite
-        monkey_patch_test_suite()
+__all__ = zmq.__all__ + ['monkey_patch']
